@@ -26,8 +26,6 @@ class ServerProtocol(asyncio.Protocol):
 
     def connection_made(self, transport):
         logger.info(id(self))
-        peername = transport.get_extra_info("peername")
-        logger.info("Connection from {}".format(peername))
         self.transport = transport
 
     def data_received(self, data):
@@ -50,7 +48,7 @@ class ServerProtocol(asyncio.Protocol):
                 logger.error(f"Unsupported mtype: {chr(mtype)}")
                 raise ValueError(f"Unsupported mtype: {chr(mtype)}")
             if self.ins:
-                self.ins(chr(mtype), self.data, **self.kwargs)
+                self.ins(self, chr(mtype), self.data, **self.kwargs)
             self.transport.write(b"success")
         except Exception as e:
             logger.error(e)
